@@ -641,12 +641,14 @@ void quit_app(GtkWidget * a, gpointer user_data)
 	/* gtk_widget_destroy(girl->record_window); */
 	if (g_main_loop_is_running (girl->player_loop)) {
 		girl_player_backend_stop(girl->player_loop);
+		girl->player_loop = NULL;
 	}
 	if (GTK_IS_WIDGET(girl->record_window)) {
 		gtk_widget_destroy(girl->record_window);
 	}
 	if (g_main_loop_is_running (girl->record_loop)) {
 		girl_record_backend_stop(girl->record_loop);
+		girl->record_loop = NULL;
 	}
 	/* girl_record_backend_stop(girl->record_loop); */
 	gtk_main_quit();
